exceptiongroup: Backport of PEP 654 (exception groups)
======================================================

Description
-----------

Backport of PEP 654 (exception groups)

License
-------

Upstream Contact
----------------

https://pypi.org/project/exceptiongroup/

